@@ -6,7 +6,9 @@ class DisambiguatedWord(Word):
 
     __parse: MorphologicalParse
 
-    def __init__(self, name: str, parse: MorphologicalParse):
+    def __init__(self,
+                 name: str,
+                 parse: MorphologicalParse):
         """
         The constructor of {@link DisambiguatedWord} class which takes a str and a MorphologicalParse
         as inputs. It creates a new MorphologicalParse with given MorphologicalParse. It generates a new instance with
@@ -28,3 +30,6 @@ class DisambiguatedWord(Word):
             MorphologicalParse.
         """
         return self.__parse
+
+    def __repr__(self):
+        return f"{self.name} {self.__parse}"
